# How to use
In version 1.0.2 of anime_gen there are only two use cases:
___
### Generate Wallpaper:

		import anime_gen
		
		print(anime_gen.wallpaper())
### Output:
	https://images8.alphacoders.com/872/872837.jpg
___
### Generate Wallpaper with discord webhook:
		import anime_gen
		
		anime_gen.imageWebhook("Your discord webhook here")
### Output in discord:
![enter image description here](https://cdn.discordapp.com/attachments/1069718308435263498/1070040906583003246/image.png)